@@ -414,6 +414,10 @@ def test_debian_build_compare2():
     assert not res
     res = utils.version_compare("7.52.1-5+deb9u7", 0, "*", None, "7.52.1-5+deb9u3")
     assert not res
+    res = utils.version_compare("1.0.2l-2+deb9u3", "*", "*", None, "1.0.2l-2+deb9u2")
+    assert not res
+    res = utils.version_compare("7.52.1-5+deb9u7", "*", "*", None, "7.52.1-5+deb9u3")
+    assert not res
     res = utils.version_compare("7.52.1-5+deb9u7", 0, "*", None, "7.52.1-5+deb9u2")
     assert not res
     res = utils.version_compare("1.7.6-2+deb9u3", 0, "*", None, "1.7.6-2+deb9u2")
@@ -449,8 +453,24 @@ def test_debian_build_compare3():
     assert res
     res = utils.version_compare("232-25+deb9u4", 0, "*", None, "232-25+deb9u8")
     assert res
+    res = utils.version_compare("232-25+deb9u4", "*", "*", None, "232-25+deb9u6")
+    assert res
+    res = utils.version_compare("232-25+deb9u4", "*", "*", None, "232-25+deb9u8")
+    assert res
     res = utils.version_compare("2.50.3-2", 0, "*", None, "2.50.3-2+deb9u1")
     assert res
+    res = utils.version_compare("2.35.2-2", 0, "*", None, "2.37-3")
+    assert res
+    res = utils.version_compare("2.35.2-2", "*", "*", None, "2.37-3")
+    assert res
+    res = utils.version_compare("2.36", "*", "*", None, "2.37-3")
+    assert res
+    res = utils.version_compare("247.3-7", "*", "*", None, "249~rc2-1")
+    assert res
+    res = utils.version_compare("247.3-7", 0, "*", None, "249~rc2-1")
+    assert res
+    res = utils.version_compare("247.3-7", "*", "*", None, "99.99.9")
+    assert res
 
 
 def test_redhat_build_compare():
