@@ -772,6 +772,7 @@ class AquaSource(NvdSource):
                 "end-of-life",
                 "ignored",
                 "not-affected",
+                "postponed",
             ):
                 continue
             pkg_name = ann.get("Package")
@@ -791,6 +792,11 @@ class AquaSource(NvdSource):
             if ":" in version:
                 version = version.split(":")[-1]
             severity = "MEDIUM"
+            # Try harder to set LOW priority
+            if kind == "postponed" or (
+                ann.get("Description") and ann.get("Description") == "Minor issue"
+            ):
+                severity = "LOW"
             if ann.get("Severity"):
                 severity = threat_to_severity.get(ann.get("Severity"), "MEDIUM")
             score, severity, vectorString, attackComplexity = get_default_cve_data(
