@@ -204,8 +204,8 @@ class OSVSource(NvdSource):
                 if vendor == "alpine":
                     vdistro = vdistro.replace("v", "")
                 edition = f"{vendor}-{vdistro}"
-                # Only use the precise version for debian
-                if "debian" in vendor:
+                # Only use the precise version for debian and alpine
+                if "debian" in vendor or "alpine" in vendor:
                     pkg_name_list = [f"{edition}/{pkg_name}"]
                 else:
                     pkg_name_list.append(f"{edition}/{pkg_name}")
